@@ -10,12 +10,9 @@ import torch.nn.functional as F
 
 from torch import Tensor
 
-# isort: off; pylint: disable=E0611,E0401
 from compressai._CXX import pmf_to_quantized_cdf as _pmf_to_quantized_cdf
 from compressai.ops import LowerBound
 
-# isort: on; pylint: enable=E0611,E0401
-
 
 class _EntropyCoder:
     """Proxy class to an actual entropy coder class."""
@@ -33,12 +30,12 @@ class _EntropyCoder:
             )
 
         if method == "ans":
-            from compressai import ans  # pylint: disable=E0611
+            from compressai import ans
 
             encoder = ans.RansEncoder()
             decoder = ans.RansDecoder()
         elif method == "rangecoder":
-            import range_coder  # pylint: disable=E0401
+            import range_coder
 
             encoder = range_coder.RangeEncoder()
             decoder = range_coder.RangeDecoder()
@@ -273,7 +270,7 @@ class EntropyModel(nn.Module):
                         raise ValueError("Invalid means parameters")
 
         cdf = self._quantized_cdf
-        outputs = cdf.new(indexes.size())
+        outputs = cdf.new_empty(indexes.size())
 
         for i, s in enumerate(strings):
             values = self.entropy_coder.decode_with_indexes(
@@ -283,7 +280,9 @@ class EntropyModel(nn.Module):
                 self._cdf_length.reshape(-1).int().tolist(),
                 self._offset.reshape(-1).int().tolist(),
             )
-            outputs[i] = torch.Tensor(values).reshape(outputs[i].size())
+            outputs[i] = torch.tensor(
+                values, device=outputs.device, dtype=outputs.dtype
+            ).reshape(outputs[i].size())
         outputs = self.dequantize(outputs, means)
         return outputs
 
@@ -352,7 +351,7 @@ class EntropyBottleneck(EntropyModel):
     def update(self, force: bool = False) -> bool:
         # Check if we need to update the bottleneck parameters, the offsets are
         # only computed and stored when the conditonal model is update()'d.
-        if self._offset.numel() > 0 and not force:  # pylint: disable=E0203
+        if self._offset.numel() > 0 and not force:
             return False
 
         medians = self.quantiles[:, 0, 1]
@@ -578,7 +577,7 @@ class GaussianConditional(EntropyModel):
         # updated.
         if self._offset.numel() > 0 and not force:
             return False
-        device = self.scale_table.device  # pylint: disable=E0203
+        device = self.scale_table.device
         self.scale_table = self._prepare_scale_table(scale_table).to(device)
         self.update()
         return True
